# this terraform module providers a kubernetes cron job that runs the pruner

terraform {
  backend "local" {}
  required_version = ">= 1.5"
  required_providers {
    kubernetes = {
      source  = "hashicorp/kubernetes"
      version = "~> 2.25"
    }
  }
}


provider "kubernetes" {
  config_path    = var.kubernetes_config_path
  config_context = var.kubernetes_context
}


variable "kubernetes_config_path" {
  type        = string
  description = "path to kubernetes config to use"
}

variable "kubernetes_context" {
  type        = string
  description = "kubernetes context to use"
}

variable "namespace" {
  type        = string
  description = "kubernetes namespace to deploy in"
}

variable "image" {
  type        = string
  description = "docker image"
  default     = "dockermirror:5000/dpedu/resticbackup:0.0.11"
}

variable "s3_uri" {
  type        = string
  description = "restic s3 uri"
}

variable "passwords" {
  type        = map(string)
  description = "restic encryption passwords"
}

variable "schedule" {
  type        = string
  description = "kubernetes cron expression"
  default     = "15 0 * * *"
}

variable "suspend" {
  type        = bool
  description = "suspend the cronjob"
  default     = false
}


resource "kubernetes_secret_v1" "passwords" {
  metadata {
    name      = "resticbackup-pruner"
    namespace = var.namespace
  }

  data = {
    passwords = jsonencode(var.passwords)
  }
}

resource "kubernetes_cron_job_v1" "scraper" {
  metadata {
    name      = "resticbackup-pruner"
    namespace = var.namespace
  }
  spec {
    schedule           = var.schedule
    concurrency_policy = "Replace"
    suspend            = var.suspend
    job_template {
      metadata {}
      spec {
        template {
          metadata {}
          spec {
            restart_policy = "Never"
            container {
              name              = "pruner"
              image             = var.image
              image_pull_policy = "Always"
              args = [
                var.s3_uri,
                "/etc/passwords.json",
              ]
              volume_mount {
                name       = "passwords"
                mount_path = "/etc/passwords.json"
                sub_path   = "passwords"
              }
            }
            volume {
              name = "passwords"
              secret {
                secret_name = kubernetes_secret_v1.passwords.metadata.0.name
              }
            }
          }
        }
      }
    }
  }
}
